![Blogorama CI](https://github.com/renderbox/django-blogorama/workflows/Blogorama%20CI/badge.svg)

![Blogorama CI](https://github.com/renderbox/django-blogorama/workflows/Blogorama%20Develop/badge.svg)

# Blogorama

Blogging App to add to any project
